@@ -1,6 +1,4 @@
 from .robot import Robot
-from signal import SIGTERM, SIGINT, SIGHUP, signal
-import sys
 
 conf = {
     "communication": {
@@ -8,10 +6,6 @@ conf = {
     }
 }
 
-def interrupt_handler(signum, frame):
-    Server.stop()
-    sys.exit()
-
 class Server():
     _is_server_started = False
 
@@ -23,10 +17,6 @@ class Server():
             print('Server already started')
             return
 
-        signal(SIGTERM, interrupt_handler)
-        signal(SIGINT, interrupt_handler)
-        signal(SIGHUP, interrupt_handler)
-
         Server._robot = Robot(conf)
         Server._is_server_started = True
         Server._robot.print_manual()
